@@ -21,7 +21,7 @@ from rest_registration.utils.users import (
     get_user_setting
 )
 from rest_registration.utils.verification import verify_signer_or_bad_request
-from rest_registration.utils.verification_notifications import (
+from rest_registration.verification_notifications import (
     send_register_verification_email_notification
 )
 
