@@ -1,7 +1,6 @@
-
 from rest_registration.settings import registration_settings
+from rest_registration.utils.signers import URLParamsSigner
 from rest_registration.utils.users import get_user_by_verification_id, get_user_setting
-from rest_registration.verification import URLParamsSigner
 
 
 class RegisterSigner(URLParamsSigner):
